% FT2025.cls — FT2025 paper class v1.0.
% by P Krus, based on FTF2019 by Liselott Ericson & Ingo Staack.

\ProvidesClass{FT2025}[2025/05/08 FT25-paper class, by P Krus, based on FTF2019]
\NeedsTeXFormat{LaTeX2e}

% Pass all options to article.
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

% Load base article class in two‑column A4 mode, 10pt.
\LoadClass[a4paper,twocolumn,10pt]{article}

% Page geometry.
\RequirePackage[a4paper,left=15mm,right=15mm,top=25mm,bottom=25mm,ignorehead]{geometry}

% Core fonts & encoding.
\RequirePackage{mathptmx}             % Times font.
\RequirePackage[scaled=.92]{helvet}   % Helvetica.
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[british]{babel}

% Captions, headers, spacing
\RequirePackage{caption}
\renewcommand{\captionfont}{\it}
\RequirePackage{fancyhdr}
\pagestyle{empty}
\setlength{\headheight}{23pt}
\renewcommand{\headrulewidth}{0pt}
\linespread{1}
\setlength{\columnsep}{8mm}
\setlength{\parindent}{0pt}
\setlength{\parskip}{1ex}

% Core packages.
\RequirePackage{graphicx}
\RequirePackage{amsmath}
\RequirePackage{booktabs}
\RequirePackage{float}
\RequirePackage{multicol}
\RequirePackage[acronym,nomain,nonumberlist,nogroupskip]{glossaries}
\RequirePackage[per-mode=symbol]{siunitx}
\RequirePackage{authblk}

% Hyperlinks & URL support.
\RequirePackage[bookmarks,hidelinks]{hyperref}
\RequirePackage{url}
% Provide \newblock for unsrt.bst.
\providecommand{\newblock}{\hskip .11em plus .33em minus .07em}

% Email macro for affiliation: simple line break + italic text.
\newcommand{\Emails}[1]{\\\textit{E‑mail:} #1}
\renewcommand{\Emails}[1]{%
	\par\smallskip               % end current paragraph, add a little vertical space.
	\noindent\textit{E‑mail:}\\ % label on its own line.
	#1                           % the address(es).
}
% Glossary setup.
\makeglossaries

% Author/Affiliation styling.
\renewcommand\Authfont{\normalsize\bfseries}
\renewcommand\Affilfont{\small\itshape}
\setcounter{Maxaffil}{0}  % numeric superscript markers.

% Banner insertion macro.
\newcommand{\FTBanner}[1]{%
	\begin{center}
		\vspace*{-17mm}% adjust vertical offset as needed.
		\includegraphics[width=0.9\textwidth]{#1}\\[12pt]%
	\end{center}%
}

% Abstract environment with adjustable width.
\renewenvironment{abstract}[1][0.75\textwidth]{%
	\begin{center}
		\vspace{6mm}
		{\Large\bfseries Abstract}\\[6pt]
		\begin{minipage}{#1}
		}{%
		\end{minipage}\\[12pt]
	\end{center}
}

% Keywords macro.
\newcommand{\keywords}[2][0.75\textwidth]{%
	\begin{center}
		\begin{minipage}{#1}
			\textbf{Keywords:} #2
			\vspace{5mm}
		\end{minipage}
	\end{center}
}

% Sectional formatting.
\renewcommand\section{\@startsection{section}{1}{\z@}%
	{-1.5ex \@plus -1ex \@minus -.2ex}%
	{0.3ex \@plus .2ex}%
	{\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
	{-1.5ex \@plus -1ex \@minus -.2ex}%
	{0.3ex \@plus .2ex}%
	{\normalfont\normalsize\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
	{-1.5ex \@plus -1ex \@minus -.2ex}%
	{0.3ex \@plus .2ex}%
	{\normalfont\normalsize\bfseries}}

% Preserve original abstract environment for compatibility.

% Override \maketitle to include fancy page style and spacing.
\renewcommand\maketitle{%
	\thispagestyle{fancy}%
	\vspace*{8mm}%
	\begingroup\centering%
	\global\@topnum\z@   % no floats at top
	{\large\bfseries\Large \@title}\\[9mm]%
	{\noindent \@author}\\[8mm]%
	\endgroup%
	\setcounter{footnote}{0}%
	\global\let\thanks\relax%
	\global\let\maketitle\relax%
}

\makeatletter
\newcommand{\clearcolumn}{%
	\par              % finish current paragraph
	\vfill            % stretch out to bottom of this column
	\columnbreak      % then break to the next column
}
\makeatother

\endinput
